# merlin-core

This repository contains core utilities for [NVIDIA Merlin](https://github.com/NVIDIA-Merlin) libraries
like [NVTabular](https://github.com/NVIDIA-Merlin/NVTabular), [Transformers4Rec](https://github.com/NVIDIA-Merlin/Transformers4Rec) 
and [merlin-models](https://github.com/NVIDIA-Merlin/models).

## Installation

To install from pypi:

```
pip install merlin-core
```

To install from conda:

```
conda install -c nvidia -c rapidsai -c numba -c conda-forge merlin-core python=3.7 cudatoolkit=11.0
```
